@@ -16,13 +16,15 @@ import os
 import sys
 from time import sleep
 import datetime
+import random
 
 # import transports and formatters
 import transports as trans
 import formatters as forms
 
-# import fake factory
+# import fakers
 from faker import Factory
+import format_mappings as fm
 
 
 DEFAULT_BASE_LOGGING_LEVEL = logging.INFO
@@ -83,7 +85,7 @@ def init_logger(base_level=DEFAULT_BASE_LOGGING_LEVEL,
 lgr = init_logger()
 
 
-def set_global_verbosity_level(is_verbose_output=False):
+def _set_global_verbosity_level(is_verbose_output=False):
     """sets the global verbosity level for console and the lgr logger.
 
     :param bool is_verbose_output: should be output be verbose
@@ -112,7 +114,7 @@ def _import_config(config_file):
         return __import__(os.path.basename(os.path.splitext(
             config_file)[0])).GENERATOR
     except ImportError:
-        lgr.error('could not import config file. please verify that '
+        lgr.error('could not import config file. jeez..please verify that '
                   'it exists in the specified path')
         # TODO: (IMPRV) add conditional raising with verbosity dependency
         # TODO: (IMPRV) throughout the code
@@ -162,6 +164,7 @@ def send(instance, client, format, format_config, messages, gap, batch):
     # and get the current time
     start_time = get_current_time()
     lgr.debug('start time is: {}'.format(start_time))
+    lgr.info('sending logs... EN GARDE!')
     while True:
         # generate the log data from the formatter
         logs = [formatter_instance.generate_data() for i in xrange(batch)]
@@ -173,7 +176,7 @@ def send(instance, client, format, format_config, messages, gap, batch):
         if message_count < messages:
             # just to get some feedback during execution
             if not message_count % (1 / gap):
-                lgr.info('{} logs written'.format(message_count))
+                lgr.info('{} logs written. NICE!'.format(message_count))
             # and sleep the desired amount of time.. zzz zz zZZ zZZzzzz
             sleep(gap)
         else:
@@ -188,16 +191,17 @@ def send(instance, client, format, format_config, messages, gap, batch):
     # TODO: add the option to send the throughput as well to benchmark
     # TODO: the logging process itself.
     lgr.info('DONE! (after {}h ({} seconds) with '
-             'throughput: {} logs/sec)'.format(
+             'throughput: {} logs/sec. now you can go for coffee.)'.format(
                  elapsed_time, seconds, throughput))
     # TODO: support retrieving data statistics from transport after
     # TODO: execution ended.
     try:
+        # create a pretty table to write the statistical data to
         data = instance.get_data()
+        lgr.info('statistical data:\n {}'.format(data))
     except AttributeError:
-        lgr.warning(
+        lgr.debug(
             'statistical data not implemented for chosen transport.')
-    lgr.info('statistical data: {}'.format(data))
     return
 
 
@@ -230,6 +234,7 @@ def generator(config=None, transport=None, formatter=None, gap=None,
     :param float gap: gap in seconds between 2 messages
     :param int messages: number of messages to send
     """
+    # TODO: DEPRECATE? maybe we do want multiple formats.. ehh..
     def _create_formats_list(formats, formats_dict):
         formats = []
         if formats:
@@ -256,21 +261,19 @@ def generator(config=None, transport=None, formatter=None, gap=None,
     if batch > int(messages):
         raise PylogError('batch number larger than total amount of messages')
     # set verbosity level for internal logging
-    set_global_verbosity_level(verbose)
+    _set_global_verbosity_level(verbose)
     # import config file with formatter and transport config
     config = _import_config(config)
     # declare transport and formatter configuration
     try:
         transport_config = config['transports'][transport]
     except KeyError:
-        raise PylogError(
-            'transport configuration not specified for {}'.format(transport))
+        lgr.debug('transport configuration not specified.')
+        transport_config = {}
     try:
         formatter_config = config['formatters'][formatter]
     except KeyError:
-        # raise PylogError(
-        #     'formatter configuration not specified for {}'.format(formatter))
-        lgr.info('formatter configuration not specified.')
+        lgr.debug('formatter configuration not specified.')
         formatter_config = []
     # configure transport instance and client
     instance, client = config_transport(trans, transport, transport_config)
@@ -281,7 +284,7 @@ def generator(config=None, transport=None, formatter=None, gap=None,
     try:
         instance.close()
     except AttributeError:
-        lgr.warning('connection closing not implemented for chosen transport.')
+        lgr.debug('connection closing not implemented for chosen transport.')
 
 
 def list_fake_types():
@@ -294,11 +297,28 @@ def list_fake_types():
         'set_formatter',
         'parse',
         'provider',
-        'providers'
+        'providers',
+        'get_providers',
     ]
+    fakes_list = []
+
+    # yes, the following is sort of disgusting. will have to find a better way
+    # to implement this...
+    # list from fake-factory
     for fake_type in dir(fake):
         if not fake_type.startswith('_') and not fake_type in ignore_list:
-            print('*** {} ({})'.format(fake_type, getattr(fake, fake_type)()))
+            fakes_list.append('*** {} ({})'.format(
+                fake_type, getattr(fake, fake_type)()))
+    # list from format mappings default handler
+    for fake_type, data in fm.DATA.items():
+        fakes_list.append('*** {} ({})'.format(fake_type, random.choice(data)))
+    # list from format mappings additional handlers
+    for fake_type in dir(fm.InHouseFaker):
+        if not fake_type.startswith('_') and not fake_type == 'default':
+            fakes_list.append('*** {} ({})'.format(
+                fake_type, getattr(fm.InHouseFaker(), fake_type)()))
+
+    print("\n".join(fakes_list))
 
 
 class PylogError(Exception):
